@@ -14,16 +14,16 @@ setClass("IdtHetNMANOVA",contains="IdtMANOVA")
 setClass("Idtlda",representation(prior="numeric",means="matrix",scaling="matrix",N="numeric"))
 setClass("Idtqda",representation(prior="numeric",means="matrix",scaling="array",ldet="numeric",lev="character"))
 
-setGeneric("summary")
 setGeneric("nrow")
 setGeneric("ncol")
-setGeneric("head",package="utils")
-setGeneric("tail",package="utils")
-setGeneric("coef",package="stats")
-setGeneric("stdEr",package="miscTools")
-setGeneric("lda",package="MASS")
-setGeneric("qda",package="MASS")
-setGeneric("predict",package="stats")
+setGeneric("summary",signature="object")
+setGeneric("head",package="utils",signature="x")
+setGeneric("tail",package="utils",signature="x")
+setGeneric("coef",package="stats",signature="object")
+setGeneric("stdEr",package="miscTools",signature="x")
+setGeneric("lda",package="MASS",signature="x")
+setGeneric("qda",package="MASS",signature="x")
+setGeneric("predict",package="stats",signature="object")
 
 setGeneric("mle",function(Idt,Model="Normal",Config=1:5,SelCrit=c("AIC","BIC"))  standardGeneric("mle"))
 setGeneric("MANOVA",function(Idt, grouping, Model="Normal", Config=1:5, SelCrit=c("AIC","BIC"), Mxt=c("Hom","Het"), tol=1.0e-4)  standardGeneric("MANOVA"))
